@@ -1,20 +1,29 @@
 #' @title Logistic Regression Classification Learner
 #'
+#' @usage NULL
 #' @aliases mlr_learners_classif.log_reg
 #' @format [R6::R6Class()] inheriting from [mlr3::LearnerClassif].
 #'
+#' @section Construction:
+#' ```
+#' LearnerClassifLogReg$new()
+#' mlr3::mlr_learners$get("classif.log_reg")
+#' mlr3::lrn("classif.log_reg")
+#' ```
+#'
 #' @description
 #' Classification via logistic regression.
 #' Calls [stats::glm()].
 #'
 #' @export
+#' @template seealso_learner
 #' @templateVar learner_name classif.log_reg
 #' @template example
 LearnerClassifLogReg = R6Class("LearnerClassifLogReg", inherit = LearnerClassif,
   public = list(
-    initialize = function(id = "classif.log_reg") {
+    initialize = function() {
       super$initialize(
-        id = id,
+        id = "classif.log_reg",
         predict_types = c("response", "prob"),
         feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
         properties = c("weights", "twoclass"),
@@ -23,7 +32,7 @@ LearnerClassifLogReg = R6Class("LearnerClassifLogReg", inherit = LearnerClassif,
     },
 
     train_internal = function(task) {
-      pars = self$param_set$get_values(tags ="train")
+      pars = self$param_set$get_values(tags = "train")
       if ("weights" %in% task$properties) {
         pars = insert_named(pars, list(weights = task$weights$weight))
       }
