@@ -1,8 +1,16 @@
 #' @title Extreme Gradiant Boosting Classification Learner
 #'
+#' @usage NULL
 #' @aliases mlr_learners_classif.xgboost
 #' @format [R6::R6Class()] inheriting from [mlr3::LearnerClassif].
 #'
+#' @section Construction:
+#' ```
+#' LearnerClassifXgboost$new()
+#' mlr3::mlr_learners$get("classif.xgboost")
+#' mlr3::lrn("classif.xgboost")
+#' ```
+#'
 #' @description
 #' eXtreme Gradient Boosting classification.
 #' Calls [xgboost::xgb.train()] from package \CRANpkg{xgboost}.
@@ -14,13 +22,14 @@
 #' \doi{10.1145/2939672.2939785}.
 #'
 #' @export
+#' @template seealso_learner
 #' @templateVar learner_name classif.xgboost
 #' @template example
 LearnerClassifXgboost = R6Class("LearnerClassifXgboost", inherit = LearnerClassif,
   public = list(
-    initialize = function(id = "classif.xgboost") {
+    initialize = function() {
       super$initialize(
-        id = id,
+        id = "classif.xgboost",
         param_set = ParamSet$new(
           params = list(
             # we pass all of what goes in 'params' directly to ... of xgboost
@@ -76,7 +85,8 @@ LearnerClassifXgboost = R6Class("LearnerClassifXgboost", inherit = LearnerClassi
     },
 
     train_internal = function(task) {
-      pars = self$param_set$get_values(tags ="train")
+
+      pars = self$param_set$get_values(tags = "train")
       lvls = task$class_names
 
       if (is.null(pars$objective)) {
@@ -108,7 +118,8 @@ LearnerClassifXgboost = R6Class("LearnerClassifXgboost", inherit = LearnerClassi
     },
 
     predict_internal = function(task) {
-      pars = self$param_set$get_values(tags ="predict")
+
+      pars = self$param_set$get_values(tags = "predict")
       response = prob = NULL
       lvls = task$class_names
       nlvl = length(lvls)
