@@ -1,20 +1,29 @@
 #' @title Linear Model Regression Learner
 #'
+#' @usage NULL
 #' @aliases mlr_learners_regr.lm
 #' @format [R6::R6Class()] inheriting from [mlr3::LearnerRegr].
 #'
+#' @section Construction:
+#' ```
+#' LearnerRegrLM$new()
+#' mlr3::mlr_learners$get("regr.lm")
+#' mlr3::lrn("regr.lm")
+#' ```
+#'
 #' @description
 #' Ordinary linear regression.
 #' Calls [stats::lm()].
 #'
 #' @export
+#' @template seealso_learner
 #' @templateVar learner_name regr.lm
 #' @template example
 LearnerRegrLM = R6Class("LearnerRegrLM", inherit = LearnerRegr,
   public = list(
-    initialize = function(id = "regr.lm", predict_type = "response") {
+    initialize = function() {
       super$initialize(
-        id = id,
+        id = "regr.lm", ,
         predict_types = c("response", "se"),
         feature_types = c("integer", "numeric", "factor"),
         properties = "weights",
@@ -23,7 +32,7 @@ LearnerRegrLM = R6Class("LearnerRegrLM", inherit = LearnerRegr,
     },
 
     train_internal = function(task) {
-      pars = self$param_set$get_values(tags ="train")
+      pars = self$param_set$get_values(tags = "train")
       if ("weights" %in% task$properties) {
         pars = insert_named(pars, list(weights = task$weights$weight))
       }
