@@ -1,7 +1,7 @@
 context("classif.naive_bayes")
 
 test_that("autotest", {
-  learner = LearnerClassifNaiveBayes$new()
+  learner = mlr3::lrn("classif.naive_bayes")
   expect_learner(learner)
   result = run_autotest(learner)
   expect_true(result, info = result$error)
