@@ -1,9 +1,8 @@
 context("regr.ranger")
 
 test_that("autotest", {
-  learner = LearnerRegrRanger$new()
+  learner = mlr3::lrn("regr.ranger", num.trees = 100, importance = "impurity")
   expect_learner(learner)
-  learner$param_set$values = list(num.trees = 100L, importance = "impurity")
   result = run_autotest(learner, N = 50L)
   expect_true(result, info = result$error)
 })
